# mypy-boto3-ecs

[![PyPI - mypy-boto3-ecs](https://img.shields.io/pypi/v/mypy-boto3-ecs.svg?color=blue)](https://pypi.org/project/mypy-boto3-ecs)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-ecs.svg?color=blue)](https://pypi.org/project/mypy-boto3-ecs)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

- [mypy-boto3-ecs](#mypy-boto3-ecs)
  - [How to use](#how-to-use)
  - [Automated type discovery](#automated-type-discovery)


Type annotations for
[boto3.ECS 1.13.26](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/ecs.html#ECS) service
compatible with [mypy](https://github.com/python/mypy), [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/) and other tools.

Generated by [mypy-boto3-buider 2.0.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

- [mypy-boto3-ecs](#mypy-boto3-ecs)
  - [How to use](#how-to-use)
    - [Type checking](#type-checking)
  - [How it works](#how-it-works)

## How to use

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `ECS` service.

```bash
python -m pip install boto3-stubs[ecs]

# update installed packages index for automated type discovery
python -m mypy_boto3
```

Use `boto3` with `mypy_boto3_ecs` in your project and enjoy type checking and auto-complete.

```python
import boto3

from mypy_boto3_ecs import ECSClient

# Now mypy can check if your code is valid.
client: ECSClient = boto3.client("ecs")

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: ECSClient = session.client("ecs")



# Waiters are also supported

import mypy_boto3_ecs.waiter as ecs_waiters

services_inactive_waiter: ecs_waiters.ServicesInactiveWaiter = client.get_waiter("services_inactive")
services_stable_waiter: ecs_waiters.ServicesStableWaiter = client.get_waiter("services_stable")
tasks_running_waiter: ecs_waiters.TasksRunningWaiter = client.get_waiter("tasks_running")
tasks_stopped_waiter: ecs_waiters.TasksStoppedWaiter = client.get_waiter("tasks_stopped")


# Annotated paginators are included as well

import mypy_boto3_ecs.paginator as ecs_paginators

list_account_settings_paginator: ecs_paginators.ListAccountSettingsPaginator = client.get_paginator("list_account_settings")
list_attributes_paginator: ecs_paginators.ListAttributesPaginator = client.get_paginator("list_attributes")
list_clusters_paginator: ecs_paginators.ListClustersPaginator = client.get_paginator("list_clusters")
list_container_instances_paginator: ecs_paginators.ListContainerInstancesPaginator = client.get_paginator("list_container_instances")
list_services_paginator: ecs_paginators.ListServicesPaginator = client.get_paginator("list_services")
list_task_definition_families_paginator: ecs_paginators.ListTaskDefinitionFamiliesPaginator = client.get_paginator("list_task_definition_families")
list_task_definitions_paginator: ecs_paginators.ListTaskDefinitionsPaginator = client.get_paginator("list_task_definitions")
list_tasks_paginator: ecs_paginators.ListTasksPaginator = client.get_paginator("list_tasks")
```

## Automated type discovery

`mypy_boto3` package can generate index for `mypy_boto3_ecs` and other installed services.

```bash
# Run this command when you add or remove service packages
python -m mypy_boto3
```

Generated index provides overloads for `boto3.client` and `boto3.service`,
`boto3.Session.client` and `boto3.Session.resource` functions,
so explicit type annotations are not needed.

- `mypy` supports function overloads as expected
- `PyCharm` also supports function overloads, but consumes a lot of RAM, use carefully
- `VSCode` does not currently support function overloads

Also, generated index allows you to import types from `mypy_boto3`:

```python
# you can replace imports
import mypy_boto3_ecs as ecs
from mypy_boto3_ecs import ECSClient

# with these
from mypy_boto3 import ecs
from mypy_boto3.ecs import ECSClient
```